@@ -83,7 +83,7 @@ def set_dataframe_columntypes(df):
     if 'LeadFollowers' in df:
         df['LeadFollowers'] = df['LeadFollowers'].astype('float64')
     if 'PreviousContacts' in df:
-        df['PreviousContacts'] = df['PreviousContacts'].astype('float16')
+        df['PreviousContacts'] = df['PreviousContacts'].astype('Int64')
     if 'PreviousStatus' in df:
         df['PreviousStatus'] = df['PreviousStatus'].astype('float16')
     if 'DaysSinceLastContact' in df:
